@@ -1,8 +1,8 @@
-#' A simple feature point data containing locations of municipalities central localities
+#' A data frame containing locations of municipalities central localities
 #'
-#' Data is extracted from latest version (April 2023) of Topographic Database (Maastotietokanta) by National Land Survey of Finland (Maanmittauslaitos)
+#' Data is extracted from latest version (April 2025) of Topographic Database (Maastotietokanta) by National Land Survey of Finland (Maanmittauslaitos)
 #'
-#' @format A simple feature POINT data with 311 rows and 21 variables:
+#' @format A data.frame with 309 rows and 19 variables:
 #' \describe{
 #'   \item{mtk_id}{mtk_id}
 #'   \item{sijaintitarkkuus}{location precision}
@@ -21,13 +21,10 @@
 #'   \item{kirjasinkallistuskulma}{kirjasinkallistuskulma}
 #'   \item{kirjasinvalyskerroin}{kirjasinvalyskerroin}
 #'   \item{kuntatunnus}{municipality code}
-#'   \item{municipality_code}{municipality code}
-#'   \item{municipality_name_fi}{municipality name in Finnish}
-#'   \item{municipality_name_sv}{municipality name in Swedish}
-#'   \item{municipality_name_en}{municipality name in English}
-#'   \item{geometry}{geometry}
+#'   \item{X}{longitude}
+#'   \item{Y}{latitude}
 #' }
-"municipality_central_localities"
+"municipality_central_localities_df"
 
 
 
@@ -791,7 +788,7 @@
 #' }
 #' @source \url{https://data.stat.fi/api/classifications/v2/classifications}
 "municipality_key_2021"
-# names(municipality_key_2021) %>% paste0("#'   \\item{",.,"}{",.,"}\n") %>% cat(., file = "tmp.txt")
+# names(municipality_key_2021) |> paste0("#'   \\item{",.,"}{",.,"}\n") |> cat(., file = "tmp.txt")
 
 
 
@@ -867,7 +864,7 @@
 #' }
 #' @source \url{https://data.stat.fi/api/classifications/v2/classifications}
 "municipality_key_2020"
-# names(municipality_key_2020) %>% paste0("#'   \\item{",.,"}{",.,"}\n") %>% cat(., file = "tmp.txt")
+# names(municipality_key_2020) |> paste0("#'   \\item{",.,"}{",.,"}\n") |> cat(., file = "tmp.txt")
 
 #' Municipality key table for 2019
 #'
@@ -1010,7 +1007,7 @@
 #' }
 #' @source \url{https://data.stat.fi/api/classifications/v2/classifications}
 "municipality_key_2018"
-# names(municipality_key_2017) %>% paste0("#'   \\item{",.,"}{",.,"}\n") %>% cat(., file = "tmp.txt")
+# names(municipality_key_2017) |> paste0("#'   \\item{",.,"}{",.,"}\n") |> cat(., file = "tmp.txt")
 
 #' municipality_key_2017
 #'
